var assert = require("assert");
var ioclient = require('socket.io-client');
var mockConfig = {
  getConf: function(){
    return {
        db: 'mongodb://localhost/cloud-cordinator-users',
        memory: '127.0.0.1',
        port: 3010,
        socketPass: 'SecretPassword'
      }
  }
}
//Mock the missing config.js file for testing on non production machines
var configPath = require.resolve('../config/conftool');
require.cache[configPath] = {exports: mockConfig};
var config = require('../config/conftool').getConf();
//Mock before calling any modules that will reference out to module
var socketOptions = {
  transport: ['websocket'],
  'force new connection' : true
}
var connector = require('../libs/connection_server');
var crypto = require('crypto');

describe('Connection Server', function(){
  before(function(done){
    connector.boot(config);
    done();
  });
  after(function(done){
    connector.stop();
    done();
  });
  it("should boot without throwing any exceptions", function(done){
    done();
  });
  it("socket-io client can connect and authenticate", function(done){
    var socketURL = 'http://0.0.0.0:' + config.port;
    var client =  ioclient.connect(socketURL, socketOptions);
    client.on("connect", function(data){
      var socketKey = {
        user :'238492823482932498',
        timestamp: new Date()
      };
      var cipher = crypto.createCipher("aes-256-cbc",config.socketPass);
      var encryptedSocketKey =  cipher.update(JSON.stringify(socketKey), 'utf8', 'base64');
      encryptedSocketKey +=  cipher.final('base64');
      var body = {status: 'ok', timestamp: socketKey.timestamp, socketKey: encryptedSocketKey};
      client.emit('auth', body);
    });
    client.on('authsuccess', function(data){
      console.log('client1 sucess'); 
      done();
      client.disconnect();
    });
  });
  it("socket-io client can connect and fails bad clients", function(done){
    console.log('starting bad client test'); 
    var socketURL = 'http://0.0.0.0:' + config.port;
    console.log(socketURL); 
    var client2 =  ioclient.connect(socketURL, socketOptions);
    client2.on("connect", function(data){
      var socketKey = {
        user :'238492823482932498',
        timestamp: new Date()
      };
      console.log('bad client connected');
      var encryptedSocketKey =  'BADDATA'
      var body = {status: 'ok', timestamp: socketKey.timestamp, socketKey: encryptedSocketKey};
      client2.emit('auth', body);
    });
    client2.on('authfailure', function(data){
      done();
    });
  });
});
